==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/mp9134_001/MP9134_AddEquipmentMeterReading_001.java <==

package net.datastream.schemas.mp_functions.mp9134_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.equipmentmeterreading_001.EquipmentMeterReading;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/EquipmentMeterReading_001}EquipmentMeterReading"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="EquipmentMeterReading" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="rollOverAllowed" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="confirm" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentMeterReading"
})
@XmlRootElement(name = "MP9134_AddEquipmentMeterReading_001")
public class MP9134_AddEquipmentMeterReading_001 {

    @XmlElement(name = "EquipmentMeterReading", namespace = "http://schemas.datastream.net/MP_entities/EquipmentMeterReading_001", required = true)
    protected EquipmentMeterReading equipmentMeterReading;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "rollOverAllowed")
    protected String rollOverAllowed;

    /**
     * Gets the value of the equipmentMeterReading property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentMeterReading }
     *     
     */
    public EquipmentMeterReading getEquipmentMeterReading() {
        return equipmentMeterReading;
    }

    /**
     * Sets the value of the equipmentMeterReading property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentMeterReading }
     *     
     */
    public void setEquipmentMeterReading(EquipmentMeterReading value) {
        this.equipmentMeterReading = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EQUIPMENT_METER_READING;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the rollOverAllowed property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRollOverAllowed() {
        if (rollOverAllowed == null) {
            return "confirm";
        } else {
            return rollOverAllowed;
        }
    }

    /**
     * Sets the value of the rollOverAllowed property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRollOverAllowed(String value) {
        this.rollOverAllowed = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_functions/mp9134_001/MP9134_AddEquipmentMeterReading_001.java <==

package net.datastream.schemas.mp_functions.mp9134_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.equipmentmeterreading_001.EquipmentMeterReading;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/EquipmentMeterReading_001}EquipmentMeterReading"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="EquipmentMeterReading" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="rollOverAllowed" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="confirm" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentMeterReading"
})
@XmlRootElement(name = "MP9134_AddEquipmentMeterReading_001")
public class MP9134_AddEquipmentMeterReading_001 {

    @XmlElement(name = "EquipmentMeterReading", namespace = "http://schemas.datastream.net/MP_entities/EquipmentMeterReading_001", required = true)
    protected EquipmentMeterReading equipmentMeterReading;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "rollOverAllowed")
    protected String rollOverAllowed;

    /**
     * Gets the value of the equipmentMeterReading property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentMeterReading }
     *     
     */
    public EquipmentMeterReading getEquipmentMeterReading() {
        return equipmentMeterReading;
    }

    /**
     * Sets the value of the equipmentMeterReading property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentMeterReading }
     *     
     */
    public void setEquipmentMeterReading(EquipmentMeterReading value) {
        this.equipmentMeterReading = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EQUIPMENT_METER_READING;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the rollOverAllowed property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRollOverAllowed() {
        if (rollOverAllowed == null) {
            return "confirm";
        } else {
            return rollOverAllowed;
        }
    }

    /**
     * Sets the value of the rollOverAllowed property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRollOverAllowed(String value) {
        this.rollOverAllowed = value;
    }

}
